@@ -1,6 +1,7 @@
 ##################################################
 package Log::Log4perl::Appender::Socket;
 ##################################################
+our @ISA = qw(Log::Log4perl::Appender);
 
 use warnings;
 use strict;
@@ -23,15 +24,18 @@ sub new {
 
     bless $self, $class;
 
-    unless($self->connect(@options)) {
-        if($self->{silent_recovery}) {
-            warn "Connect to $self->{PeerAddr}:$self->{PeerPort} failed: $!";
-            return $self;
+    unless ($self->{defer_connection}){
+        unless($self->connect(@options)) {
+            if($self->{silent_recovery}) {
+               warn "Connect to $self->{PeerAddr}:$self->{PeerPort} failed: $!";
+               return $self;
+            }
+            die "Connect to $self->{PeerAddr}:$self->{PeerPort} failed: $!";
         }
-        die "Connect to $self->{PeerAddr}:$self->{PeerPort} failed: $!";
-    }
 
-    $self->{socket}->autoflush(1);
+        $self->{socket}->autoflush(1); 
+        #autoflush has been the default behavior since 1997
+    }
 
     return $self;
 }
@@ -51,11 +55,12 @@ sub log {
 ##################################################
     my($self, %params) = @_;
 
+
     {
             # If we were never able to establish
             # a connection, try to establish one 
             # here. If it fails, return.
-        if($self->{silent_recovery} and 
+        if(($self->{silent_recovery} or $self->{defer_connection}) and 
            !defined $self->{socket}) {
             if(! $self->connect(%$self)) {
                 return undef;
@@ -67,7 +72,7 @@ sub log {
              };
 
         if($@) {
-            warn "Send to " . ref($self) . " failed ($@)";
+            warn "Send to " . ref($self) . " failed ($@), retrying once...";
             if($self->connect(%$self)) {
                 redo;
             }
@@ -133,6 +138,13 @@ can't be established at initialization time, a single warning is issued.
 Every log attempt will then try to establish the connection and 
 discard the message silently if it fails.
 
+Connecting at initialization time may not be the best option when
+running under Apache1 Apache2/prefork, because the parent process creates
+the socket and the connections are shared among the forked children--all
+the children writing to the same socket could intermingle messages.  So instead
+of that, you can use C<defer_connection> which will put off making the
+connection until the first log message is sent.
+
 =head1 EXAMPLE
 
 Write a server quickly using the IO::Socket::INET module:
